==> haskell-bifunctors-5.2.1-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-bifunctors/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bifunctors
version: 5.2.1
id: bifunctors-5.2.1-854727fccb4481ffefcc20f535d6c50b
key: bifun_Fh2tqVLz3Uq0CGtYaC81jh
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/bifunctors/
synopsis: Bifunctors
description:
    Bifunctors
category: Data, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Biapplicative Data.Bifoldable Data.Bifunctor.Biff
    Data.Bifunctor.Clown Data.Bifunctor.Fix Data.Bifunctor.Flip
    Data.Bifunctor.Functor Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Sum Data.Bifunctor.Tannen
    Data.Bifunctor.TH Data.Bifunctor.Wrapped Data.Bitraversable
hidden-modules: Data.Bifunctor.TH.Internal Paths_bifunctors
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/bifunctors-5.2.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/bifunctors-5.2.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/bifunctors-5.2.1
hs-libraries: HSbifunctors-5.2.1-Fh2tqVLz3Uq0CGtYaC81jh
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    comonad-5-a91321d086a2de4a04a44d60c347669e
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html: /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bifunctors-5.2.1-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-bifunctors/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bifunctors
version: 5.2.1
id: bifunctors-5.2.1-3dea194c07c9b02982b78a82398333cc
key: bifun_2t2qRIffaTj78px8UA9i8X
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/bifunctors/
synopsis: Bifunctors
description:
    Bifunctors
category: Data, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Biapplicative Data.Bifoldable Data.Bifunctor.Biff
    Data.Bifunctor.Clown Data.Bifunctor.Fix Data.Bifunctor.Flip
    Data.Bifunctor.Functor Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Sum Data.Bifunctor.Tannen
    Data.Bifunctor.TH Data.Bifunctor.Wrapped Data.Bitraversable
hidden-modules: Data.Bifunctor.TH.Internal Paths_bifunctors
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/bifunctors-5.2.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/bifunctors-5.2.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/bifunctors-5.2.1
hs-libraries: HSbifunctors-5.2.1-2t2qRIffaTj78px8UA9i8X
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    comonad-5-e98e7adc8875accf64a86529d9aeae51
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html: /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
